﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.ExcelExporter;
using Infragistics.Documents.Excel;
using System.Data;

namespace ExportHierarchyXDGaligned
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataSet set = new DataSet();
            //Add two tables
            set.Tables.Add(BuildTable("Parent"));
            set.Tables.Add(BuildChildTable("Child"));

            //Create relations
            DataColumn parentColumn = set.Tables[0].Columns["id"];
            DataColumn childColumn = set.Tables[1].Columns["relation"];
            DataRelation relation = new DataRelation("RelationName", parentColumn, childColumn);
            set.Relations.Add(relation);

            xdg.DataSource = set.Tables[0].DefaultView;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
         
            DataPresenterExcelExporter exporter = new DataPresenterExcelExporter();
            exporter.CellExporting += new EventHandler<Infragistics.Windows.DataPresenter.ExcelExporter.CellExportingEventArgs>(exporter_CellExporting);
            exporter.HeaderLabelExporting += new EventHandler<HeaderLabelExportingEventArgs>(exporter_HeaderLabelExporting);
            exporter.Export(xdg, "xamDataPresenter1.xlsx", WorkbookFormat.Excel2007);
        }



        void exporter_HeaderLabelExporting(object sender, HeaderLabelExportingEventArgs e)
        {

            if (e.Record.RecordManager.ParentRecord != null && e.CurrentColumnIndex >= 1)
            {

                e.Workbook.Worksheets[0].Rows[e.CurrentRowIndex].Cells[e.CurrentColumnIndex - 1].Value = e.Field.Label;
                if (e.CurrentColumnIndex == (e.Record as DataRecord).Cells.Count)
                {
                    e.Cancel = true;
                    return;
                }
            }
        }

        void exporter_CellExporting(object sender, Infragistics.Windows.DataPresenter.ExcelExporter.CellExportingEventArgs e)
        {
           
            if (e.Record.RecordManager.ParentRecord!=null&& e.CurrentColumnIndex>=1)
            {
              
                e.Workbook.Worksheets[0].Rows[e.CurrentRowIndex].Cells[e.CurrentColumnIndex - 1].Value = (e.Record as DataRecord).Cells[e.Field].Value;
                if (e.CurrentColumnIndex == (e.Record as DataRecord).Cells.Count)
                {
                    e.Cancel = true;
                    return;
                }
            }           
            
        }

        void xamDataGrid1_RecordExpanded(object sender, Infragistics.Windows.DataPresenter.Events.RecordExpandedEventArgs e)
        {
            foreach (DataRecord d in xdg.Records)
            {
                foreach (ExpandableFieldRecord c in d.ChildRecords)
                    c.DataPresenter.Width = d.Cells[0].DataPresenter.Width;
            }
        }


        void LabelPresenter_changesize(object sender, SizeChangedEventArgs e)
        {
            if (xdg.FieldLayouts[0].Fields.Contains((sender as LabelPresenter).Field))
            {
                xdg.FieldLayouts[1].Fields[(sender as LabelPresenter).Field.Name].Width = new FieldLength((sender as LabelPresenter).Field.LabelWidthResolved);
            }
            else
            {
                if ((sender as LabelPresenter).Field.Width != null)
                    xdg.FieldLayouts[0].Fields[(sender as LabelPresenter).Field.Name].Width = new FieldLength((sender as LabelPresenter).Field.LabelWidthResolved);
            }
        }
//hierarchichal data
        private DataTable BuildTable(string name)
        {

            System.Data.DataTable table = new DataTable(name);
            DataColumn column;
            DataRow row;

            column = new DataColumn();
            column.DataType = System.Type.GetType("System.Int32");
            column.ColumnName = "id";
            column.ReadOnly = true;
            table.Columns.Add(column);

            column = new DataColumn();
            column.DataType = System.Type.GetType("System.String");
            column.ColumnName = "Item";
            column.AutoIncrement = false;
            column.Caption = "Item";
            column.ReadOnly = false;
            column.Unique = false;
            table.Columns.Add(column);

            column = new DataColumn();
            column.DataType = System.Type.GetType("System.String");
            column.ColumnName = "Data";
            column.AutoIncrement = false;
            column.Caption = "Data";
            column.ReadOnly = false;
            column.Unique = false;
            table.Columns.Add(column);

            DataColumn[] PrimaryKeyColumns = new DataColumn[1];
            PrimaryKeyColumns[0] = table.Columns["id"];
            table.PrimaryKey = PrimaryKeyColumns;

            for (int i = 0; i <= 20; i++)
            {
                row = table.NewRow();
                row["id"] = i;
                row["Item"] = "Item " + i;
                row["Data"] = "Data " + i;
                table.Rows.Add(row);
            }
            return table;

        }

        private DataTable BuildChildTable(string name)
        {
            System.Data.DataTable table = new DataTable(name);
            DataColumn column;
            DataRow row;

            column = new DataColumn();
            column.DataType = System.Type.GetType("System.Int32");
            column.ColumnName = "id";
            column.ReadOnly = true;
            table.Columns.Add(column);

            column = new DataColumn();
            column.DataType = System.Type.GetType("System.String");
            column.ColumnName = "Item";
            column.AutoIncrement = false;
            column.Caption = "Item";
            column.ReadOnly = false;
            column.Unique = false;
            table.Columns.Add(column);

            column = new DataColumn();
            column.DataType = System.Type.GetType("System.String");
            column.ColumnName = "Data";
            column.AutoIncrement = false;
            column.Caption = "Data";
            column.ReadOnly = false;
            column.Unique = false;
            table.Columns.Add(column);


            column = new DataColumn();
            column.DataType = System.Type.GetType("System.Int32");
            column.ColumnName = "relation";
            column.AutoIncrement = false;
            column.Caption = "relation";
            column.ReadOnly = false;
            column.Unique = false;
            table.Columns.Add(column);

            DataColumn[] PrimaryKeyColumns = new DataColumn[1];
            PrimaryKeyColumns[0] = table.Columns["id"];
            table.PrimaryKey = PrimaryKeyColumns;

            for (int i = 0; i <= 100; i++)
            {
                row = table.NewRow();
                row["id"] = i;
                row["Item"] = "Item " + i;
                row["Data"] = "Data " + i;

                if ((i < 10) && (i >= 0))
                {

                    row["relation"] = 0;
                }
                else if ((i < 20) && (i >= 10))
                {
                    row["relation"] = 1;
                }
                else if ((i < 30) && (i >= 20))
                {
                    row["relation"] = 2;
                }
                else if ((i < 40) && (i >= 30))
                {
                    row["relation"] = 3;
                }
                else if ((i < 50) && (i >= 40))
                {
                }
                table.Rows.Add(row);
            }
            return table;

        }
    }
}
